Skip to contents

Finds the row indices of specified WAV files within the metadata of a Sound Analysis Pro (SAP) object.

Usage

get_wav_indices(sap, wav_files)

Arguments

sap

A SAP object

wav_files

A character vector of WAV file names

Value

A numeric vector representing the row indices of the specified WAV files in the SAP object's metadata.