R/utillties.R
get_wav_indices.Rd
Finds the row indices of specified WAV files within the metadata of a Sound Analysis Pro (SAP) object.
get_wav_indices(sap, wav_files)
A SAP object
A character vector of WAV file names
A numeric vector representing the row indices of the specified WAV files in the SAP object's metadata.